@@ -407,9 +407,8 @@ int dpi_scale(int value) {
 }
 
 #ifdef BUILD_GUI
-conky::gradient_factory *create_gradient_factory(int width,
-                                                 unsigned long first_colour,
-                                                 unsigned long last_colour) {
+conky::gradient_factory *create_gradient_factory(int width, Colour first_colour,
+                                                 Colour last_colour) {
   switch (graph_gradient_mode.get(*state)) {
     case RGB_GRADIENT:
       return new conky::rgb_gradient_factory(width, first_colour, last_colour);
@@ -1283,7 +1282,7 @@ int draw_each_line_inner(char *s, int special_index, int last_special_applied) {
         case GRAPH:
           if (display_output() && display_output()->graphical()) {
             int h, by, i = 0, j = 0;
-            //int colour_idx = 0;
+            int colour_idx = 0;
             Colour last_colour = current_color;
             if (cur_x - text_start_x > mw && mw > 0) { break; }
             h = current->height;
@@ -1310,18 +1309,18 @@ int draw_each_line_inner(char *s, int special_index, int last_special_applied) {
 
             /* in case we don't have a graph yet */
             if (current->graph != nullptr) {
-              std::unique_ptr<unsigned long[]> tmpcolour;
+              std::unique_ptr<Colour[]> tmpcolour;
 
-              if (current->last_colour != 0 || current->first_colour != 0) {
+              if (current->colours_set) {
                 auto factory = create_gradient_factory(w, current->last_colour,
                                                        current->first_colour);
                 tmpcolour = factory->create_gradient();
                 delete factory;
               }
-              //colour_idx = 0;
+              colour_idx = 0;
               for (i = w - 2; i > -1; i--) {
-                if (current->last_colour != 0 || current->first_colour != 0) {
-                  /*if (current->tempgrad != 0) {
+                if (current->colours_set) {
+                  if (current->tempgrad != 0) {
                     set_foreground_color(tmpcolour[static_cast<int>(
                         static_cast<float>(w - 2) -
                         current->graph[j] * (w - 2) /
@@ -1329,7 +1328,7 @@ int draw_each_line_inner(char *s, int special_index, int last_special_applied) {
                                      1.0F))]);
                   } else {
                     set_foreground_color(tmpcolour[colour_idx++]);
-                  }*/
+                  }
                 }
                 /* this is mugfugly, but it works */
                 if (display_output()) {
