@@ -606,14 +606,10 @@ void display_output_x11::cleanup() {
 }
 
 void display_output_x11::set_foreground_color(Colour c) {
+  current_color = c;
 #ifdef BUILD_ARGB
   if (have_argb_visual) {
-    current_color = c;
     current_color.alpha = own_window_argb_value.get(*state);
-  } else {
-#endif /* BUILD_ARGB */
-    current_color = c;
-#ifdef BUILD_ARGB
   }
 #endif /* BUILD_ARGB */
   XSetForeground(display, window.gc, current_color.to_x11_color(display, screen));
@@ -642,8 +638,8 @@ int display_output_x11::calc_text_width(const char *s) {
 void display_output_x11::draw_string_at(int x, int y, const char *s, int w) {
 #ifdef BUILD_XFT
   if (use_xft.get(*state)) {
-    XColor c;
-    XftColor c2;
+    XColor c{};
+    XftColor c2{};
 
     c.pixel = current_color.to_x11_color(display, screen);
     // query color on custom colormap
